documentationtools.FunctionCrawler
==================================

.. abjad-lineage:: abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.FunctionCrawler

.. autoclass:: abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.FunctionCrawler
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.FunctionCrawler.code_root
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.FunctionCrawler.include_private_objects
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.FunctionCrawler.module_crawler
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.FunctionCrawler.root_package_name
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.FunctionCrawler.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.FunctionCrawler.__call__
   :noindex:

.. automethod:: abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.FunctionCrawler.__eq__
   :noindex:

.. automethod:: abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.FunctionCrawler.__ge__
   :noindex:

.. automethod:: abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.FunctionCrawler.__gt__
   :noindex:

.. automethod:: abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.FunctionCrawler.__le__
   :noindex:

.. automethod:: abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.FunctionCrawler.__lt__
   :noindex:

.. automethod:: abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.FunctionCrawler.__ne__
   :noindex:

.. automethod:: abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.FunctionCrawler.__repr__
   :noindex:
